Skip to contents

Compute the closed-form two-arm CMR allocation for a supplied nonnegative variance rectangle for unbounded outcomes.

Usage

cmr_unbounded_from_rectangle(rectangle)

Arguments

rectangle

Two-arm nonnegative variance rectangle with names v_l1, v_u1, v_l0, and v_u0.

Value

A list of class cmr_unbounded and cmr_two_arm with treatment share pi, CMR certificate U_CMR, rectangle, corner regrets, binding diagnostics, and method metadata.

Examples

rect <- c(v_l1 = 0.5, v_u1 = 1.4, v_l0 = 0.2, v_u0 = 1.0)
cmr_unbounded_from_rectangle(rect)
#> <cmr_unbounded>
#>   pi: 0.566383
#>   U_CMR: 0.274763
#>   method: unbounded_mom