Stratified variance objectives and Neyman allocation
Source:R/cmr_stratified.R
stratified_variance_objective.RdHelper functions for stratified two-arm variance objectives, oracle values, Neyman allocations, regret, and rectangle vertices.
Usage
stratified_variance_objective(pi, variances, strata_share)
stratified_oracle_variance(variances, strata_share)
assign_stratified_neyman(variances, strata_share)
stratified_regret(pi, variances, strata_share)
stratified_rectangle_vertices(rectangle, strata_share, max_vertices = 65536L)Arguments
- pi
Assignment shares for each treatment/control by stratum cell. A vector should be named like
"1:A"and"0:A", or a2 x Smatrix with treatment and control rows.- variances
Cell variances as a
2 x Smatrix or data frame with treatment and control rows.Named stratum population shares that sum to one.
- rectangle
Stratified variance rectangle, a list with
lowerandupper2 x Smatrices.- max_vertices
Maximum number of hyperrectangle vertices to enumerate.
Value
Numeric objective/regret values, named assignment vectors, or a vertex matrix.
assign_stratified_neyman() returns total assignment shares over
treatment/control by stratum cells.
See also
Other assignment helpers:
assign_balance(),
multiarm_variance_objective(),
realize_allocation(),
variance_objective()
Other rectangle helpers:
binary_rectangle_corners(),
cmr_multiarm_from_rectangle(),
cmr_stratified_from_rectangle(),
cmr_unbounded_from_rectangle(),
folded_binomial_pmf(),
multiarm_variance_objective(),
rectangle_bernoulli_binary(),
rectangle_bounded_two_arm(),
rectangle_multiarm(),
rectangle_multiple_outcomes(),
rectangle_proxy(),
rectangle_stratified(),
rectangle_unbounded(),
variance_bounds_bernoulli_exact(),
variance_bounds_maurer_pontil(),
variance_bounds_unbounded_mom()