Exact one-arm variance confidence bounds for Bernoulli outcomes using the folded-binomial distribution of the sample variance.
Value
A list with lower bound L, upper bound U, folded-binomial variance
estimate vhat, method name, sample size n, and folded-count details in
statistic.
See also
Other rectangle helpers:
binary_rectangle_corners(),
cmr_multiarm_from_rectangle(),
cmr_stratified_from_rectangle(),
cmr_unbounded_from_rectangle(),
folded_binomial_pmf(),
multiarm_variance_objective(),
rectangle_bernoulli_binary(),
rectangle_bounded_two_arm(),
rectangle_multiarm(),
rectangle_multiple_outcomes(),
rectangle_proxy(),
rectangle_stratified(),
rectangle_unbounded(),
stratified_variance_objective(),
variance_bounds_maurer_pontil(),
variance_bounds_unbounded_mom()
Examples
y <- c(1, 0, 1, 1, 0, 0, 1, 0)
variance_bounds_bernoulli_exact(y, beta_l = 0.025, beta_u = 0.025)
#> $L
#> [1] 0.1374708
#>
#> $U
#> [1] 0.25
#>
#> $vhat
#> [1] 0.25
#>
#> $method
#> [1] "bernoulli"
#>
#> $n
#> [1] 8
#>
#> $statistic
#> $statistic$j
#> [1] 4
#>
#> $statistic$x
#> [1] 4
#>
#> $statistic$m
#> [1] 8
#>
#> $statistic$raw_sample_variance
#> [1] 0.2857143
#>
#> $statistic$beta_l
#> [1] 0.025
#>
#> $statistic$beta_u
#> [1] 0.025
#>
#>